imblearn.under_sampling.NeighbourhoodCleaningRule
=================================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: NeighbourhoodCleaningRule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NeighbourhoodCleaningRule.__init__
      ~NeighbourhoodCleaningRule.fit
      ~NeighbourhoodCleaningRule.fit_sample
      ~NeighbourhoodCleaningRule.get_params
      ~NeighbourhoodCleaningRule.sample
      ~NeighbourhoodCleaningRule.set_params
   
   

   
   
   